@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-"""Client-side API dedicated to HaveIBeenPwned API.
+"""Bot using the HaveIBeenPwned for bulk-checking domain breaches.
 
 """
 from ...apis import HaveIBeenPwnedAPI
@@ -10,7 +10,7 @@ __all__ = ["HaveIBeenPwnedBot"]
 
 class HaveIBeenPwnedBot(HaveIBeenPwnedAPI):
     """
-    HaveIBeenPwnedBot class for requesting information using the HaveIBeenPwned? API.
+    Class for requesting information using the HaveIBeenPwned? API.
     
     :param kwargs: JSONBot / API keyword-arguments
     """
